/* BASSWMA 2.3 C/C++ header file, copyright (c) 2002-2006 Ian Luck.
   Requires BASS 2.3 - available from www.un4seen.com

   See the BASSWMA.CHM file for more complete documentation */

#ifndef BASSWMA_H
#define BASSWMA_H

#include "bass.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef BASSWMADEF
#define BASSWMADEF(f) WINAPI f
#endif

typedef DWORD HWMENCODE;		// WMA encoding handle

// Additional error codes returned by BASS_ErrorGetCode
#define BASS_ERROR_WMA_LICENSE	1000	// the file is protected
#define BASS_ERROR_WMA			1001	// Windows Media (9 or above) is not installed
#define BASS_ERROR_WMA_WM9		BASS_ERROR_WMA
#define BASS_ERROR_WMA_DENIED	1002	// access denied (user/pass is invalid)
#define BASS_ERROR_WMA_INDIVIDUAL 1004	// individualization is needed

// Additional config options
#define BASS_CONFIG_WMA_PRECHECK	0x10100
#define BASS_CONFIG_WMA_PREBUF		0x10101
#define BASS_CONFIG_WMA_ASX			0x10102

// additional WMA sync type
#define BASS_SYNC_WMA_CHANGE	1001

// additional BASS_StreamGetFilePosition WMA mode
#define BASS_FILEPOS_WMA_BUFFER	1000 // internet buffering progress (0-100%)

// Additional flags for use with BASS_WMA_EncodeOpen/File/Network/Publish
#define BASS_WMA_ENCODE_SCRIPT	0x20000 // set script (mid-stream tags) in the WMA encoding

// Additional flag for use with BASS_WMA_EncodeGetRates
#define BASS_WMA_ENCODE_RATES_VBR	0x10000 // get available VBR quality settings

typedef void (CALLBACK CLIENTCONNECTPROC)(HWMENCODE handle, BOOL connect, const char *ip, DWORD user);
/* Client connection notification callback function.
handle : The encoder
connect: TRUE=client is connecting, FALSE=disconnecting
ip     : The client's IP (xxx.xxx.xxx.xxx:port)
user   : The 'user' parameter value given when calling BASS_EncodeSetNotify */

typedef void (CALLBACK WMENCODEPROC)(HWMENCODE handle, DWORD type, const void *buffer, DWORD length, DWORD user);
/* Encoder callback function.
handle : The encoder handle
type   : The type of data, one of BASS_WMA_ENCODE_xxx values
buffer : The encoded data
length : Length of the data
user   : The 'user' parameter value given when calling BASS_WMA_EncodeOpen */

// WMENCODEPROC "type" values
#define BASS_WMA_ENCODE_HEAD	0
#define BASS_WMA_ENCODE_DATA	1
#define BASS_WMA_ENCODE_DONE	2

// BASS_WMA_EncodeSetTag "type" values
#define BASS_WMA_TAG_ANSI		0
#define BASS_WMA_TAG_UNICODE	1
#define BASS_WMA_TAG_UTF8		2

// BASS_CHANNELINFO type
#define BASS_CTYPE_STREAM_WMA		0x10300
#define BASS_CTYPE_STREAM_WMA_MP3	0x10301

// Additional BASS_ChannelGetTags type
#define BASS_TAG_WMA		8	// WMA tags : array of null-terminated UTF-8 strings


HSTREAM BASSWMADEF(BASS_WMA_StreamCreateFile)(BOOL mem, const void *file, DWORD offset, DWORD length, DWORD flags);
HSTREAM BASSWMADEF(BASS_WMA_StreamCreateFileAuth)(BOOL mem, const void *file, DWORD offset, DWORD length, DWORD flags, const char *user, const char *pass);
HSTREAM BASSWMADEF(BASS_WMA_StreamCreateFileUser)(DWORD flags, STREAMFILEPROC *proc, DWORD user);

const DWORD *BASSWMADEF(BASS_WMA_EncodeGetRates)(DWORD freq, DWORD chans, DWORD flags);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpen)(DWORD freq, DWORD chans, DWORD flags, DWORD bitrate, WMENCODEPROC *proc, DWORD user);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenFile)(DWORD freq, DWORD chans, DWORD flags, DWORD bitrate, const char *file);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenNetwork)(DWORD freq, DWORD chans, DWORD flags, DWORD bitrate, DWORD port, DWORD clients);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenNetworkMulti)(DWORD freq, DWORD chans, DWORD flags, const DWORD *bitrates, DWORD port, DWORD clients);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenPublish)(DWORD freq, DWORD chans, DWORD flags, DWORD bitrate, const char *url, const char *user, const char *pass);
HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenPublishMulti)(DWORD freq, DWORD chans, DWORD flags, const DWORD *bitrates, const char *url, const char *user, const char *pass);
DWORD BASSWMADEF(BASS_WMA_EncodeGetPort)(HWMENCODE handle);
BOOL BASSWMADEF(BASS_WMA_EncodeSetNotify)(HWMENCODE handle, CLIENTCONNECTPROC *proc, DWORD user);
DWORD BASSWMADEF(BASS_WMA_EncodeGetClients)(HWMENCODE handle);
BOOL BASSWMADEF(BASS_WMA_EncodeSetTag)(HWMENCODE handle, const char *tag, const char *text, DWORD type);
BOOL BASSWMADEF(BASS_WMA_EncodeWrite)(HWMENCODE handle, const void *buffer, DWORD length);
BOOL BASSWMADEF(BASS_WMA_EncodeClose)(HWMENCODE handle);

void *BASSWMADEF(BASS_WMA_GetWMObject)(DWORD handle);

#ifdef __cplusplus
}
#endif

#endif
